<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>License</source>
        <translation>授權條款</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <location filename="../about.cpp" line="52"/>
        <source>Changelog</source>
        <translation>變更紀錄</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>關閉（&amp;C）</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="47"/>
        <source>GUI for applying assorted useful tweaks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>launches brightness-systray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>opens with display tab open.  Only valid with Xfce desktop running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Opens theme tab directly.  Valid on Xfce &amp; Fluxbox desktops</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>主窗口</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>軟件（xrandr）亮度</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>硬件背光</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="33"/>
        <source>MX-Tweak</source>
        <translation>MX-調整</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="58"/>
        <source>Display</source>
        <translation>顯示</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="63"/>
        <source>&amp;Quit</source>
        <translation>＆退出</translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="56"/>
        <location filename="../defaultlook.cpp" line="81"/>
        <location filename="../defaultlook.cpp" line="631"/>
        <location filename="../defaultlook.cpp" line="650"/>
        <location filename="../defaultlook.cpp" line="659"/>
        <location filename="../defaultlook.cpp" line="706"/>
        <location filename="../defaultlook.cpp" line="714"/>
        <location filename="../defaultlook.cpp" line="741"/>
        <location filename="../defaultlook.cpp" line="744"/>
        <source>MX Tweak</source>
        <translation>MX 調校</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="32"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;自訂邊條&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="46"/>
        <location filename="../defaultlook.ui" line="159"/>
        <source>Panel</source>
        <translation>邊條</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="66"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;設定視窗行為與捷徑&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="80"/>
        <source>Window Manager</source>
        <translation>視窗管理程式</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="100"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;自訂桌面外觀&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="114"/>
        <source>Appearance</source>
        <translation>外觀</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="293"/>
        <source>Backup current panel configuration</source>
        <translation>備份目前使用的邊條設定</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="440"/>
        <location filename="../defaultlook.ui" line="485"/>
        <location filename="../defaultlook.ui" line="640"/>
        <location filename="../defaultlook.ui" line="965"/>
        <location filename="../defaultlook.ui" line="972"/>
        <location filename="../defaultlook.ui" line="979"/>
        <location filename="../defaultlook.ui" line="1050"/>
        <location filename="../defaultlook.ui" line="1336"/>
        <location filename="../defaultlook.ui" line="1645"/>
        <location filename="../defaultlook.ui" line="1798"/>
        <source>Apply</source>
        <translation>使用</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="303"/>
        <location filename="../defaultlook.ui" line="363"/>
        <source>Options</source>
        <translation>選項</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="191"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;影響到所有邊條&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="266"/>
        <location filename="../defaultlook.ui" line="1632"/>
        <source>Affects 1st panel</source>
        <translation>影響到第一條邊條</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="396"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;視窗按鈕&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="251"/>
        <source>Restore default panel</source>
        <translation>回復成預設邊條</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="330"/>
        <source>Restore backup panel configuration</source>
        <translation>由備份檔回復邊條設定</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="383"/>
        <location filename="../defaultlook.ui" line="1609"/>
        <source>Left</source>
        <translation>左側</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="388"/>
        <location filename="../defaultlook.ui" line="1619"/>
        <source>Right</source>
        <translation>右側</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="241"/>
        <source>Display panel vertically</source>
        <translation>邊條垂直顯示</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="234"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Tasklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="221"/>
        <location filename="../defaultlook.ui" line="1604"/>
        <source>Bottom</source>
        <translation>下側</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="226"/>
        <location filename="../defaultlook.ui" line="1614"/>
        <source>Top</source>
        <translation>上側</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="184"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="167"/>
        <source>Display panel horizontally</source>
        <translation>邊條水平顯示</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="177"/>
        <source>Volume</source>
        <translation>儲存設備</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="198"/>
        <source>Set Tasklist plugin to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="273"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Panel Plugin Scales&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="323"/>
        <source>Power Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="353"/>
        <source>Set Scales</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="417"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Docklike is the modern dock plugin for the panel.  Window Buttons is the classic tasklist without dock features.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="464"/>
        <source>Theme</source>
        <translation>佈景</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="472"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="508"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation>使用暗色系佈景時，校正 HexChat 的輸入區</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="515"/>
        <source>Preview</source>
        <translation>預覽</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="522"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>使用暗色系佈景時，校正某些網站的欄位</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="525"/>
        <source>Firefox dark theme tweak</source>
        <translation>Firefox 暗色系佈景調校</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="532"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Manager&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="539"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Themes&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="546"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Application&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="566"/>
        <source>Save Current Settings as a Theme Set</source>
        <translation>將當前設置另存為主題集</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="577"/>
        <source>Remove User Theme Set</source>
        <translation>刪除用戶主題集</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="593"/>
        <source>Theme Options</source>
        <translation>佈景選項 </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="616"/>
        <source>Undo</source>
        <translation>復原</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="626"/>
        <location filename="../defaultlook.ui" line="667"/>
        <source>Compositor</source>
        <translation>桌面排版程式</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="660"/>
        <source>Transparency and shadow options</source>
        <translation>視窗透明化與投射陰影的選項</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="674"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>利用文字編緝程式直接修改 compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="677"/>
        <source>Edit compton.conf</source>
        <translation>編緝 compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="727"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;更改VBlank模式可能有助於減輕某些屏幕撕裂問題。有關更多信息，請參見「幫助」。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="730"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="738"/>
        <source>auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="743"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="748"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="753"/>
        <source>off</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="774"/>
        <source>None</source>
        <translation>無</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="779"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Xfwm（Xfce）桌面排版程式</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="784"/>
        <source>Compton </source>
        <translation>Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="792"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;設定 Xfce 的桌面排版程式&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="795"/>
        <source>Xfwm Settings</source>
        <translation>設定 Xfwm</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="806"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>啟動 compton-conf 設定工具</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="809"/>
        <source>Compton settings</source>
        <translation>設定 Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="823"/>
        <source>Display</source>
        <translation>顯示</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="831"/>
        <source>Hardware Backlight</source>
        <translation>硬件背光</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="838"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;顯示調整&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="865"/>
        <source>Choose Display for xrandr tweaks</source>
        <translation>為xrandr調整選擇顯示</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="875"/>
        <source>Resolution</source>
        <translation>解析度</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="882"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;按顯示保存&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="885"/>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="892"/>
        <source>Software (xrandr) Brightness</source>
        <translation>軟件（xrandr）亮度</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="899"/>
        <location filename="../defaultlook.ui" line="996"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="906"/>
        <source>GTK scaling</source>
        <translation>GTK 縮放</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="926"/>
        <source>xrandr Scaling</source>
        <translation>xrandr 縮放比例</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1022"/>
        <source>Config Options</source>
        <translation>設定選項</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1123"/>
        <location filename="../defaultlook.ui" line="1302"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>在 Thunar 檔案管理員中啟用游標單擊</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1137"/>
        <source>( also turns off Client Side Decorations for Xfce applications)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1081"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>註：若欲休眠，swap 必須大於 RAM</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1088"/>
        <location filename="../defaultlook.ui" line="1708"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>在邊條中顯示來自所有工作區的視窗</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1102"/>
        <location filename="../defaultlook.ui" line="1500"/>
        <source>Thunar windows always open in split view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1061"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>在登出選單中啟用休眠選項</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1109"/>
        <source>Enable single-click on desktop</source>
        <translation>在桌面上啟用游標單擊</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1030"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>在桌面上，不把過長檔名簡化顯示</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1037"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1095"/>
        <location filename="../defaultlook.ui" line="1454"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>將 Thunar 當中右鍵的自訂動作回復成系統預設的動作</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1130"/>
        <source>Enable Desktop Zoom </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1116"/>
        <location filename="../defaultlook.ui" line="1410"/>
        <source>Thunar split view opens horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1147"/>
        <source>Show percentages in notifcations when available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1157"/>
        <source>Fluxbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1165"/>
        <source>Reset DefaultDock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1172"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1180"/>
        <location filename="../defaultlook.ui" line="1475"/>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1185"/>
        <location filename="../defaultlook.ui" line="1480"/>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1203"/>
        <source>Manage Tint2 Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1214"/>
        <source>Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1288"/>
        <location filename="../defaultlook.ui" line="1541"/>
        <source>Autohide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1295"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1309"/>
        <source>Reset Fluxbox Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1316"/>
        <location filename="../defaultlook.ui" line="1568"/>
        <location filename="../defaultlook.ui" line="1593"/>
        <source>Placement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1323"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Thunar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1417"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1434"/>
        <source>Toggle icon captions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1461"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Add new default menu items, if any, to existing fluxbox menu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1464"/>
        <source>Upgrade existing menu entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1485"/>
        <source>On Hover</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1493"/>
        <source>Toggle desktop icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1507"/>
        <location filename="../defaultlook.ui" line="1656"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1527"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1534"/>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1548"/>
        <source>Show Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1578"/>
        <source>Plasma</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1668"/>
        <source>Workspace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1675"/>
        <source>Enable single-click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1586"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1718"/>
        <source>Other</source>
        <translation>其它</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1823"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>容許並非 root 的使用者掛載內接式硬碟</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1816"/>
        <source>Use tearfree radeon driver option</source>
        <translation>使用無淚radeon驅動程序選項</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1809"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>         注意：現有的/etc/X11/xorg.conf.d/20-amd.conf將備份到主文件夾
</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1871"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>          注意：現有的/etc/X11/xorg.conf.d/20-radeon.conf將備份到主文件夾</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1864"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1733"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;requires reboot&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1736"/>
        <source>Enable Bluetooth Adapters on boot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1857"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>註：現所採用的 /etc/X11/xorg.conf.d/20-intel.conf 會備份到家目錄當中</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1771"/>
        <source>Password for administrative tasks:</source>
        <translation>管理任務的密碼：</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1850"/>
        <source>&amp;User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1830"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>使用英特爾驅動代替默認的「模式設置」驅動（需要重啟）。</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1778"/>
        <source>Use tearfree amdgpu option</source>
        <translation>使用無淚amdgpu選項</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1726"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>將 Lightdm（登入畫面）回復成系統預設的佈景</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1764"/>
        <source>Root</source>
        <translation>最高用戶</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1743"/>
        <source>Enable kernel sandbox</source>
        <translation>啟用內核沙箱</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1785"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1750"/>
        <source>Automatic generation of fluxbox applications menu after package installation, removal, and updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1940"/>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1951"/>
        <source>Help</source>
        <translation>說明</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1968"/>
        <source>Quit application</source>
        <translation>退出程式</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1971"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1978"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1998"/>
        <source>Xfce Settings</source>
        <translation>設定 Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="57"/>
        <source>--display switch only valid for Xfce</source>
        <translation>--display開關僅對Xfce有效</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="140"/>
        <source>Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="630"/>
        <source>About MX Tweak</source>
        <translation>關於 MX 調校</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="632"/>
        <source>Version: </source>
        <translation>版本：</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="633"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>本程式可快速更換與調校預設介面佈景</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="635"/>
        <source>Copyright (c) MX Linux</source>
        <translation>版權所有 (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="636"/>
        <source>%1 License</source>
        <translation>%1 許可</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="650"/>
        <source>%1 Help</source>
        <translation>%1 幫助</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="660"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>完成！可能需要重新啟動 Firefox，這些變動才會生效。</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="707"/>
        <source>Plese remove special characters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="707"/>
        <source>from file name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="714"/>
        <source>File name already exists.  Choose another name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="742"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="745"/>
        <source>Archive does not contain a panel config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="931"/>
        <source>Panel settings</source>
        <translation>邊條設定</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="932"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>您當前的面板設置已備份到主文件夾（~/ .restore/）中名為.restore的隱藏文件夾中。</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1713"/>
        <source>settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="2053"/>
        <source>Choose a theme set</source>
        <translation>選擇一套佈景組合</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>刪除用戶主題集</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>新主題集</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>輸入新主題集的名稱</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation>視窗按鈕</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;外觀&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>顯示按鈕標籤</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>顯示扁平按鈕</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>顯示控制把</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>排序：</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>時間戳記</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>群組標題與時間戳記</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>視窗標題</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>群組標題與視窗標題</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>無，允許拖放</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;行為&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>視窗群組：</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>永不</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>總是</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>中鍵點擊動作：</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>不動作</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>關閉視窗</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>最小化視窗</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>還原最小化視窗至目前工作區</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>當滑鼠停在按鈕上時繪製視窗框架</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>用滑鼠滾輪切換視窗</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;過濾方式&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>顯示所有工作區視域內的視窗</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>只顯示最小化的視窗</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>顯示所有螢幕的視窗</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>對話視窗</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>彈出式視窗</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>移動視窗時</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;不透明度設定&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>視窗裝飾</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>在塢區視窗下顯示陰影</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>在彈出式視窗下顯示陰影</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>調整視窗大小時</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>在一般視窗下顯示陰影</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;功能設定&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>循環切換時，顯示視窗預覽而非圖示</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>以直接覆蓋視窗的方式顯示全螢幕</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>非活動中視窗</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>將圖形同步到垂直空白</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="23"/>
        <source>Xfwm Compositor Settings</source>
        <translation>設定 Xfwm 桌面排版程式</translation>
    </message>
</context>
</TS>
